@@ -68,6 +68,10 @@ gboolean _wnck_get_cardinal_list (Window   xwindow,
 char**   _wnck_get_utf8_list     (Window   xwindow,
                                   Atom     atom);
 
+void     _wnck_set_utf8_list     (Window   xwindow,
+                                  Atom     atom,
+                                  char   **list);
+
 void _wnck_error_trap_push (void);
 int  _wnck_error_trap_pop  (void);
 
@@ -84,7 +88,8 @@ void _wnck_iconify   (Window xwindow);
 void _wnck_deiconify (Window xwindow);
 
 void _wnck_close     (Screen *screen,
-		      Window  xwindow);
+		      Window  xwindow,
+		      Time    timestamp);
 
 void _wnck_change_state     (Screen  *screen,
 			     Window   xwindow,
@@ -98,12 +103,18 @@ void _wnck_activate         (Screen  *screen,
 			     Window   xwindow);
 void _wnck_activate_workspace (Screen *screen,
 			       int     new_active_space);
+void _wnck_change_viewport (Screen *screen,
+			    int     x,
+			    int     y);
 
 Window _wnck_get_group_leader   (Window xwindow);
 char*  _wnck_get_session_id     (Window xwindow);
 int    _wnck_get_pid            (Window xwindow);
 char*  _wnck_get_name           (Window xwindow);
 char*  _wnck_get_res_class_utf8 (Window xwindow);
+void   _wnck_get_wmclass        (Window xwindow,
+                                 char **res_class,
+                                 char **res_name);
 
 void   _wnck_select_input     (Window xwindow,
                                int    mask);
